==> qtwebengine-everywhere-src-6.4.3.tar.xz: qtwebengine-everywhere-src-6.4.3/src/3rdparty/chromium/chrome/browser/resources/print_preview/print_preview.ts <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

export {CrButtonElement} from 'chrome://resources/cr_elements/cr_button/cr_button.m.js';
export {CrCheckboxElement} from 'chrome://resources/cr_elements/cr_checkbox/cr_checkbox.m.js';
export {CrIconButtonElement} from 'chrome://resources/cr_elements/cr_icon_button/cr_icon_button.m.js';
export {PluralStringProxyImpl as PrintPreviewPluralStringProxyImpl} from 'chrome://resources/js/plural_string_proxy.js';
export {IronMeta} from 'chrome://resources/polymer/v3_0/iron-meta/iron-meta.js';
export {Cdd, MediaSizeCapability, MediaSizeOption, VendorCapabilityValueType} from './data/cdd.js';
export {ColorMode, createDestinationKey, Destination, DestinationOrigin, GooglePromotedDestinationId, makeRecentDestination, PDF_DESTINATION_KEY, PrinterType, RecentDestination} from './data/destination.js';
// <if expr="chromeos_ash or chromeos_lacros">
export {SAVE_TO_DRIVE_CROS_DESTINATION_KEY} from './data/destination.js';
// </if>
export {DestinationErrorType, DestinationStore, DestinationStoreEventType} from './data/destination_store.js';
export {PageLayoutInfo} from './data/document_info.js';
export {ExtensionDestinationInfo, LocalDestinationInfo} from './data/local_parsers.js';
export {CustomMarginsOrientation, Margins, MarginsSetting, MarginsType} from './data/margins.js';
export {MeasurementSystem, MeasurementSystemUnitType} from './data/measurement_system.js';
export {DuplexMode, DuplexType, getInstance, PolicyObjectEntry, PrintPreviewModelElement, PrintTicket, SerializedSettings, Setting, whenReady} from './data/model.js';
// <if expr="chromeos_ash or chromeos_lacros">
export {PrintServerStore, PrintServerStoreEventType} from './data/print_server_store.js';
// </if>
// <if expr="chromeos_ash or chromeos_lacros">
export {PrinterState, PrinterStatus, PrinterStatusReason, PrinterStatusSeverity} from './data/printer_status_cros.js';
// </if>
export {ScalingType} from './data/scaling.js';
export {Size} from './data/size.js';
export {Error, State} from './data/state.js';
export {BackgroundGraphicsModeRestriction, CapabilitiesResponse, ColorModeRestriction, DuplexModeRestriction, NativeInitialSettings, NativeLayer, NativeLayerImpl} from './native_layer.js';
// <if expr="chromeos_ash or chromeos_lacros">
export {PinModeRestriction} from './native_layer.js';
export {NativeLayerCros, NativeLayerCrosImpl, PrinterSetupResponse, PrintServersConfig} from './native_layer_cros.js';
// </if>
export {getSelectDropdownBackground, Range} from './print_preview_utils.js';
export {PrintPreviewAdvancedSettingsDialogElement} from './ui/advanced_settings_dialog.js';
export {PrintPreviewAdvancedSettingsItemElement} from './ui/advanced_settings_item.js';
export {PrintPreviewAppElement} from './ui/app.js';
export {PrintPreviewButtonStripElement} from './ui/button_strip.js';
export {PrintPreviewColorSettingsElement} from './ui/color_settings.js';
export {DEFAULT_MAX_COPIES, PrintPreviewCopiesSettingsElement} from './ui/copies_settings.js';
// <if expr="not chromeos_ash and not chromeos_lacros">
export {PrintPreviewDestinationDialogElement} from './ui/destination_dialog.js';
// </if>
// <if expr="chromeos_ash or chromeos_lacros">
export {PrintPreviewDestinationDialogCrosElement} from './ui/destination_dialog_cros.js';
export {PrintPreviewDestinationDropdownCrosElement} from './ui/destination_dropdown_cros.js';
// </if>
export {PrintPreviewDestinationListElement} from './ui/destination_list.js';
// <if expr="not chromeos_ash and not chromeos_lacros">
export {PrintPreviewDestinationListItemElement} from './ui/destination_list_item.js';
// </if>
// <if expr="chromeos_ash or chromeos_lacros">
export {PrintPreviewDestinationListItemElement} from './ui/destination_list_item_cros.js';
// </if>
// <if expr="not chromeos_ash and not chromeos_lacros">
export {PrintPreviewDestinationSelectElement} from './ui/destination_select.js';
// </if>
// <if expr="chromeos_ash or chromeos_lacros">
export {PrintPreviewDestinationSelectCrosElement} from './ui/destination_select_cros.js';
// </if>
export {DestinationState, NUM_PERSISTED_DESTINATIONS, PrintPreviewDestinationSettingsElement} from './ui/destination_settings.js';
export {LabelledDpiCapability, PrintPreviewDpiSettingsElement} from './ui/dpi_settings.js';
export {PrintPreviewDuplexSettingsElement} from './ui/duplex_settings.js';
export {PrintPreviewHeaderElement} from './ui/header.js';
export {PrintPreviewLayoutSettingsElement} from './ui/layout_settings.js';
// <if expr="not chromeos_ash and not chromeos_lacros">
export {PrintPreviewLinkContainerElement} from './ui/link_container.js';
// </if>
export {PrintPreviewMarginControlElement} from './ui/margin_control.js';
export {PrintPreviewMarginControlContainerElement} from './ui/margin_control_container.js';
export {PrintPreviewMarginsSettingsElement} from './ui/margins_settings.js';
export {PrintPreviewMediaSizeSettingsElement} from './ui/media_size_settings.js';
export {PrintPreviewNumberSettingsSectionElement} from './ui/number_settings_section.js';
export {PrintPreviewOtherOptionsSettingsElement} from './ui/other_options_settings.js';
export {PrintPreviewPagesPerSheetSettingsElement} from './ui/pages_per_sheet_settings.js';
export {PagesValue, PrintPreviewPagesSettingsElement} from './ui/pages_settings.js';
// <if expr="chromeos_ash or chromeos_lacros">
export {PrintPreviewPinSettingsElement} from './ui/pin_settings.js';
// </if>
export {PluginProxy, PluginProxyImpl, ViewportChangedCallback} from './ui/plugin_proxy.js';
export {PreviewAreaState, PreviewTicket, PrintPreviewPreviewAreaElement} from './ui/preview_area.js';
export {PrintPreviewSearchBoxElement} from './ui/print_preview_search_box.js';
export {PrintPreviewScalingSettingsElement} from './ui/scaling_settings.js';
export {SelectMixin, SelectMixinInterface} from './ui/select_mixin.js';
export {SettingsMixinInterface} from './ui/settings_mixin.js';
export {PrintPreviewSettingsSelectElement} from './ui/settings_select.js';
export {PrintPreviewSidebarElement} from './ui/sidebar.js';

==> qtwebengine-everywhere-src-6.9.3.tar.xz: qtwebengine-everywhere-src-6.9.3/src/3rdparty/chromium/chrome/browser/resources/print_preview/print_preview.ts <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

export {CrButtonElement} from 'chrome://resources/cr_elements/cr_button/cr_button.js';
export {CrCheckboxElement} from 'chrome://resources/cr_elements/cr_checkbox/cr_checkbox.js';
export {CrIconButtonElement} from 'chrome://resources/cr_elements/cr_icon_button/cr_icon_button.js';
export {CrInputElement} from 'chrome://resources/cr_elements/cr_input/cr_input.js';
export {PluralStringProxyImpl as PrintPreviewPluralStringProxyImpl} from 'chrome://resources/js/plural_string_proxy.js';
export {getTrustedHTML} from 'chrome://resources/js/static_types.js';
export {IronMeta} from 'chrome://resources/polymer/v3_0/iron-meta/iron-meta.js';
export {Cdd, ColorOption, DpiOption, DuplexOption, MediaSizeCapability, MediaSizeOption, MediaTypeCapability, MediaTypeOption, PageOrientationOption, SelectOption, VendorCapabilityValueType} from './data/cdd.js';
export {ColorMode, createDestinationKey, Destination, DestinationOrigin, GooglePromotedDestinationId, makeRecentDestination, PDF_DESTINATION_KEY, PrinterType, RecentDestination} from './data/destination.js';
// <if expr="is_chromeos">
export {SAVE_TO_DRIVE_CROS_DESTINATION_KEY} from './data/destination.js';
// </if>
export {DestinationErrorType, DestinationStore, DestinationStoreEventType} from './data/destination_store.js';
export {PageLayoutInfo} from './data/document_info.js';
export {ExtensionDestinationInfo, LocalDestinationInfo} from './data/local_parsers.js';
export {CustomMarginsOrientation, Margins, MarginsSetting, MarginsType} from './data/margins.js';
export {MeasurementSystem, MeasurementSystemUnitType} from './data/measurement_system.js';
export {DuplexMode, DuplexType, getInstance, PolicyObjectEntry, PrintPreviewModelElement, PrintTicket, SerializedSettings, Setting, Settings, whenReady} from './data/model.js';
// <if expr="is_chromeos">
export {PrintServerStore, PrintServerStoreEventType} from './data/print_server_store.js';
// </if>
// <if expr="is_chromeos">
export {PrinterState, PrinterStatus, PrinterStatusReason, PrinterStatusSeverity} from './data/printer_status_cros.js';
// </if>
export {ScalingType} from './data/scaling.js';
export {Size} from './data/size.js';
export {Error, State} from './data/state.js';
export {BackgroundGraphicsModeRestriction, CapabilitiesResponse, ColorModeRestriction, DuplexModeRestriction, NativeInitialSettings, NativeLayer, NativeLayerImpl} from './native_layer.js';
// <if expr="is_chromeos">
export {PinModeRestriction} from './native_layer.js';
export {NativeLayerCros, NativeLayerCrosImpl, PrinterSetupResponse, PrintServersConfig} from './native_layer_cros.js';
// </if>
export {getSelectDropdownBackground, Range} from './print_preview_utils.js';
export {PrintPreviewAdvancedSettingsDialogElement} from './ui/advanced_settings_dialog.js';
export {PrintPreviewAdvancedSettingsItemElement} from './ui/advanced_settings_item.js';
export {PrintPreviewAppElement} from './ui/app.js';
export {PrintPreviewButtonStripElement} from './ui/button_strip.js';
export {PrintPreviewColorSettingsElement} from './ui/color_settings.js';
export {DEFAULT_MAX_COPIES, PrintPreviewCopiesSettingsElement} from './ui/copies_settings.js';
// <if expr="not is_chromeos">
export {PrintPreviewDestinationDialogElement} from './ui/destination_dialog.js';
// </if>
// <if expr="is_chromeos">
export {DESTINATION_DIALOG_CROS_LOADING_TIMER_IN_MS, PrintPreviewDestinationDialogCrosElement} from './ui/destination_dialog_cros.js';
export {PrintPreviewDestinationDropdownCrosElement} from './ui/destination_dropdown_cros.js';
// </if>
export {PrintPreviewDestinationListElement} from './ui/destination_list.js';
// <if expr="not is_chromeos">
export {PrintPreviewDestinationListItemElement} from './ui/destination_list_item.js';
// </if>
// <if expr="is_chromeos">
export {PrintPreviewDestinationListItemElement} from './ui/destination_list_item_cros.js';
// </if>
// <if expr="not is_chromeos">
export {PrintPreviewDestinationSelectElement} from './ui/destination_select.js';
// </if>
// <if expr="is_chromeos">
export {PrintPreviewDestinationSelectCrosElement} from './ui/destination_select_cros.js';
// </if>
export {DestinationState, NUM_PERSISTED_DESTINATIONS, PrintPreviewDestinationSettingsElement} from './ui/destination_settings.js';
export {LabelledDpiCapability, PrintPreviewDpiSettingsElement} from './ui/dpi_settings.js';
export {PrintPreviewDuplexSettingsElement} from './ui/duplex_settings.js';
export {PrintPreviewHeaderElement} from './ui/header.js';
export {PrintPreviewLayoutSettingsElement} from './ui/layout_settings.js';
// <if expr="not is_chromeos">
export {PrintPreviewLinkContainerElement} from './ui/link_container.js';
// </if>
export {PrintPreviewMarginControlElement} from './ui/margin_control.js';
export {PrintPreviewMarginControlContainerElement} from './ui/margin_control_container.js';
export {PrintPreviewMarginsSettingsElement} from './ui/margins_settings.js';
export {PrintPreviewMediaSizeSettingsElement} from './ui/media_size_settings.js';
export {PrintPreviewMediaTypeSettingsElement} from './ui/media_type_settings.js';
export {PrintPreviewNumberSettingsSectionElement} from './ui/number_settings_section.js';
export {PrintPreviewOtherOptionsSettingsElement} from './ui/other_options_settings.js';
export {PrintPreviewPagesPerSheetSettingsElement} from './ui/pages_per_sheet_settings.js';
export {PagesValue, PrintPreviewPagesSettingsElement} from './ui/pages_settings.js';
// <if expr="is_chromeos">
export {PrintPreviewPinSettingsElement} from './ui/pin_settings.js';
// </if>
export {PluginProxy, PluginProxyImpl, ViewportChangedCallback} from './ui/plugin_proxy.js';
export {PreviewAreaState, PreviewTicket, PrintPreviewPreviewAreaElement} from './ui/preview_area.js';
export {PrintPreviewSearchBoxElement} from './ui/print_preview_search_box.js';
// <if expr="is_chromeos">
export {PrinterSetupInfoInitiator, PrinterSetupInfoMessageType, PrintPreviewPrinterSetupInfoCrosElement} from './ui/printer_setup_info_cros.js';
// </if>
export {PrintPreviewScalingSettingsElement} from './ui/scaling_settings.js';
// <if expr="is_chromeos">
export {SearchableDropDownCrosElement} from './ui/searchable_drop_down_cros.js';
// </if>
export {SelectMixin, SelectMixinInterface} from './ui/select_mixin.js';
export {SettingsMixinInterface} from './ui/settings_mixin.js';
export {PrintPreviewSettingsSelectElement} from './ui/settings_select.js';
export {PrintPreviewSidebarElement} from './ui/sidebar.js';
